@@ -46,6 +46,8 @@ class QWebEngineClientCertificateSelection;
 class QWebEngineClientCertificateStore;
 class QWebEngineClientHints;
 class QWebEngineDesktopMediaRequest;
+class QWebEngineExtensionInfo;
+class QWebEngineExtensionManager;
 class QWebEngineFindTextResult;
 class QWebEngineFrame;
 class QWebEngineFullScreenRequest;
@@ -85,82 +87,84 @@ enum [[deprecated]] : int {
     SBK_QWEBENGINEDOWNLOADREQUEST_SAVEPAGEFORMAT_IDX         = 40,
     SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADINTERRUPTREASON_IDX = 36,
     SBK_QWEBENGINEDOWNLOADREQUEST_IDX                        = 34,
-    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_HANDLETYPE_IDX     = 46,
-    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX     = 44,
+    SBK_QWEBENGINEEXTENSIONINFO_IDX                          = 42,
+    SBK_QWEBENGINEEXTENSIONMANAGER_IDX                       = 44,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_HANDLETYPE_IDX     = 50,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX     = 48,
     SBK_QFLAGS_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX = 4,
-    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_IDX                = 42,
-    SBK_QWEBENGINEFINDTEXTRESULT_IDX                         = 48,
-    SBK_QWEBENGINEFRAME_IDX                                  = 50,
-    SBK_QWEBENGINEFULLSCREENREQUEST_IDX                      = 52,
-    SBK_QWEBENGINEGLOBALSETTINGS_SECUREDNSMODE_IDX           = 58,
-    SBK_QTWEBENGINECOREQWEBENGINEGLOBALSETTINGS_IDX          = 54,
-    SBK_QWEBENGINEGLOBALSETTINGS_DNSMODE_IDX                 = 56,
-    SBK_QWEBENGINEHISTORY_IDX                                = 60,
-    SBK_QWEBENGINEHISTORYITEM_IDX                            = 62,
-    SBK_QWEBENGINEHISTORYMODEL_ROLES_IDX                     = 66,
-    SBK_QWEBENGINEHISTORYMODEL_IDX                           = 64,
-    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 70,
-    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 68,
-    SBK_QWEBENGINELOADINGINFO_LOADSTATUS_IDX                 = 76,
-    SBK_QWEBENGINELOADINGINFO_ERRORDOMAIN_IDX                = 74,
-    SBK_QWEBENGINELOADINGINFO_IDX                            = 72,
-    SBK_QWEBENGINENAVIGATIONREQUEST_NAVIGATIONTYPE_IDX       = 82,
-    SBK_QWEBENGINENAVIGATIONREQUEST_NAVIGATIONREQUESTACTION_IDX = 80,
-    SBK_QWEBENGINENAVIGATIONREQUEST_IDX                      = 78,
-    SBK_QWEBENGINENEWWINDOWREQUEST_DESTINATIONTYPE_IDX       = 86,
-    SBK_QWEBENGINENEWWINDOWREQUEST_IDX                       = 84,
-    SBK_QWEBENGINENOTIFICATION_IDX                           = 88,
-    SBK_QWEBENGINEPAGE_WEBACTION_IDX                         = 108,
-    SBK_QWEBENGINEPAGE_FINDFLAG_IDX                          = 96,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_IDX                = 46,
+    SBK_QWEBENGINEFINDTEXTRESULT_IDX                         = 52,
+    SBK_QWEBENGINEFRAME_IDX                                  = 54,
+    SBK_QWEBENGINEFULLSCREENREQUEST_IDX                      = 56,
+    SBK_QWEBENGINEGLOBALSETTINGS_SECUREDNSMODE_IDX           = 62,
+    SBK_QTWEBENGINECOREQWEBENGINEGLOBALSETTINGS_IDX          = 58,
+    SBK_QWEBENGINEGLOBALSETTINGS_DNSMODE_IDX                 = 60,
+    SBK_QWEBENGINEHISTORY_IDX                                = 64,
+    SBK_QWEBENGINEHISTORYITEM_IDX                            = 66,
+    SBK_QWEBENGINEHISTORYMODEL_ROLES_IDX                     = 70,
+    SBK_QWEBENGINEHISTORYMODEL_IDX                           = 68,
+    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 74,
+    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 72,
+    SBK_QWEBENGINELOADINGINFO_LOADSTATUS_IDX                 = 80,
+    SBK_QWEBENGINELOADINGINFO_ERRORDOMAIN_IDX                = 78,
+    SBK_QWEBENGINELOADINGINFO_IDX                            = 76,
+    SBK_QWEBENGINENAVIGATIONREQUEST_NAVIGATIONTYPE_IDX       = 86,
+    SBK_QWEBENGINENAVIGATIONREQUEST_NAVIGATIONREQUESTACTION_IDX = 84,
+    SBK_QWEBENGINENAVIGATIONREQUEST_IDX                      = 82,
+    SBK_QWEBENGINENEWWINDOWREQUEST_DESTINATIONTYPE_IDX       = 90,
+    SBK_QWEBENGINENEWWINDOWREQUEST_IDX                       = 88,
+    SBK_QWEBENGINENOTIFICATION_IDX                           = 92,
+    SBK_QWEBENGINEPAGE_WEBACTION_IDX                         = 112,
+    SBK_QWEBENGINEPAGE_FINDFLAG_IDX                          = 100,
     SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX                   = 6,
-    SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX                     = 110,
-    SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX                  = 104,
-    SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX                    = 102,
-    SBK_QWEBENGINEPAGE_FEATURE_IDX                           = 92,
-    SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX                 = 94,
-    SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX     = 98,
-    SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX    = 106,
-    SBK_QWEBENGINEPAGE_LIFECYCLESTATE_IDX                    = 100,
-    SBK_QWEBENGINEPAGE_IDX                                   = 90,
-    SBK_QWEBENGINEPERMISSION_PERMISSIONTYPE_IDX              = 114,
-    SBK_QWEBENGINEPERMISSION_STATE_IDX                       = 116,
-    SBK_QWEBENGINEPERMISSION_IDX                             = 112,
-    SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX                  = 120,
-    SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX        = 122,
-    SBK_QWEBENGINEPROFILE_PERSISTENTPERMISSIONSPOLICY_IDX    = 124,
-    SBK_QWEBENGINEPROFILE_IDX                                = 118,
-    SBK_QWEBENGINEPROFILEBUILDER_IDX                         = 126,
-    SBK_QWEBENGINEQUOTAREQUEST_IDX                           = 128,
-    SBK_QWEBENGINEREGISTERPROTOCOLHANDLERREQUEST_IDX         = 130,
-    SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX                  = 134,
-    SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX                   = 136,
-    SBK_QWEBENGINESCRIPT_IDX                                 = 132,
-    SBK_QWEBENGINESCRIPTCOLLECTION_IDX                       = 138,
-    SBK_QWEBENGINESETTINGS_FONTFAMILY_IDX                    = 142,
-    SBK_QWEBENGINESETTINGS_WEBATTRIBUTE_IDX                  = 150,
-    SBK_QWEBENGINESETTINGS_FONTSIZE_IDX                      = 144,
-    SBK_QWEBENGINESETTINGS_UNKNOWNURLSCHEMEPOLICY_IDX        = 148,
-    SBK_QWEBENGINESETTINGS_IMAGEANIMATIONPOLICY_IDX          = 146,
-    SBK_QWEBENGINESETTINGS_IDX                               = 140,
-    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 156,
-    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 154,
-    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 152,
-    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 158,
-    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 162,
-    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 160,
-    SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX                       = 170,
-    SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX                  = 168,
-    SBK_QWEBENGINEURLSCHEME_FLAG_IDX                         = 166,
+    SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX                     = 114,
+    SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX                  = 108,
+    SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX                    = 106,
+    SBK_QWEBENGINEPAGE_FEATURE_IDX                           = 96,
+    SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX                 = 98,
+    SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX     = 102,
+    SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX    = 110,
+    SBK_QWEBENGINEPAGE_LIFECYCLESTATE_IDX                    = 104,
+    SBK_QWEBENGINEPAGE_IDX                                   = 94,
+    SBK_QWEBENGINEPERMISSION_PERMISSIONTYPE_IDX              = 118,
+    SBK_QWEBENGINEPERMISSION_STATE_IDX                       = 120,
+    SBK_QWEBENGINEPERMISSION_IDX                             = 116,
+    SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX                  = 124,
+    SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX        = 126,
+    SBK_QWEBENGINEPROFILE_PERSISTENTPERMISSIONSPOLICY_IDX    = 128,
+    SBK_QWEBENGINEPROFILE_IDX                                = 122,
+    SBK_QWEBENGINEPROFILEBUILDER_IDX                         = 130,
+    SBK_QWEBENGINEQUOTAREQUEST_IDX                           = 132,
+    SBK_QWEBENGINEREGISTERPROTOCOLHANDLERREQUEST_IDX         = 134,
+    SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX                  = 138,
+    SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX                   = 140,
+    SBK_QWEBENGINESCRIPT_IDX                                 = 136,
+    SBK_QWEBENGINESCRIPTCOLLECTION_IDX                       = 142,
+    SBK_QWEBENGINESETTINGS_FONTFAMILY_IDX                    = 146,
+    SBK_QWEBENGINESETTINGS_WEBATTRIBUTE_IDX                  = 154,
+    SBK_QWEBENGINESETTINGS_FONTSIZE_IDX                      = 148,
+    SBK_QWEBENGINESETTINGS_UNKNOWNURLSCHEMEPOLICY_IDX        = 152,
+    SBK_QWEBENGINESETTINGS_IMAGEANIMATIONPOLICY_IDX          = 150,
+    SBK_QWEBENGINESETTINGS_IDX                               = 144,
+    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 160,
+    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 158,
+    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 156,
+    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 162,
+    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 166,
+    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 164,
+    SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX                       = 174,
+    SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX                  = 172,
+    SBK_QWEBENGINEURLSCHEME_FLAG_IDX                         = 170,
     SBK_QFLAGS_QWEBENGINEURLSCHEME_FLAG_IDX                  = 8,
-    SBK_QWEBENGINEURLSCHEME_IDX                              = 164,
-    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 172,
-    SBK_QWEBENGINEWEBAUTHPINREQUEST_IDX                      = 174,
-    SBK_QWEBENGINEWEBAUTHUXREQUEST_WEBAUTHUXSTATE_IDX        = 184,
-    SBK_QWEBENGINEWEBAUTHUXREQUEST_PINENTRYREASON_IDX        = 180,
-    SBK_QWEBENGINEWEBAUTHUXREQUEST_PINENTRYERROR_IDX         = 178,
-    SBK_QWEBENGINEWEBAUTHUXREQUEST_REQUESTFAILUREREASON_IDX  = 182,
-    SBK_QWEBENGINEWEBAUTHUXREQUEST_IDX                       = 176,
-    SBK_QTWEBENGINECORE_IDX_COUNT                            = 186,
+    SBK_QWEBENGINEURLSCHEME_IDX                              = 168,
+    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 176,
+    SBK_QWEBENGINEWEBAUTHPINREQUEST_IDX                      = 178,
+    SBK_QWEBENGINEWEBAUTHUXREQUEST_WEBAUTHUXSTATE_IDX        = 188,
+    SBK_QWEBENGINEWEBAUTHUXREQUEST_PINENTRYREASON_IDX        = 184,
+    SBK_QWEBENGINEWEBAUTHUXREQUEST_PINENTRYERROR_IDX         = 182,
+    SBK_QWEBENGINEWEBAUTHUXREQUEST_REQUESTFAILUREREASON_IDX  = 186,
+    SBK_QWEBENGINEWEBAUTHUXREQUEST_IDX                       = 180,
+    SBK_QTWEBENGINECORE_IDX_COUNT                            = 190,
 };
 
 // Type indices
@@ -183,82 +187,84 @@ enum : int {
     SBK_QWebEngineDownloadRequest_SavePageFormat_IDX         = 20,
     SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX = 18,
     SBK_QWebEngineDownloadRequest_IDX                        = 17,
-    SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX     = 23,
-    SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX     = 22,
+    SBK_QWebEngineExtensionInfo_IDX                          = 21,
+    SBK_QWebEngineExtensionManager_IDX                       = 22,
+    SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX     = 25,
+    SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX     = 24,
     SBK_QFlags_QWebEngineFileSystemAccessRequest_AccessFlag_IDX = 2,
-    SBK_QWebEngineFileSystemAccessRequest_IDX                = 21,
-    SBK_QWebEngineFindTextResult_IDX                         = 24,
-    SBK_QWebEngineFrame_IDX                                  = 25,
-    SBK_QWebEngineFullScreenRequest_IDX                      = 26,
-    SBK_QWebEngineGlobalSettings_SecureDnsMode_IDX           = 29,
-    SBK_QtWebEngineCoreQWebEngineGlobalSettings_IDX          = 27,
-    SBK_QWebEngineGlobalSettings_DnsMode_IDX                 = 28,
-    SBK_QWebEngineHistory_IDX                                = 30,
-    SBK_QWebEngineHistoryItem_IDX                            = 31,
-    SBK_QWebEngineHistoryModel_Roles_IDX                     = 33,
-    SBK_QWebEngineHistoryModel_IDX                           = 32,
-    SBK_QWebEngineHttpRequest_Method_IDX                     = 35,
-    SBK_QWebEngineHttpRequest_IDX                            = 34,
-    SBK_QWebEngineLoadingInfo_LoadStatus_IDX                 = 38,
-    SBK_QWebEngineLoadingInfo_ErrorDomain_IDX                = 37,
-    SBK_QWebEngineLoadingInfo_IDX                            = 36,
-    SBK_QWebEngineNavigationRequest_NavigationType_IDX       = 41,
-    SBK_QWebEngineNavigationRequest_NavigationRequestAction_IDX = 40,
-    SBK_QWebEngineNavigationRequest_IDX                      = 39,
-    SBK_QWebEngineNewWindowRequest_DestinationType_IDX       = 43,
-    SBK_QWebEngineNewWindowRequest_IDX                       = 42,
-    SBK_QWebEngineNotification_IDX                           = 44,
-    SBK_QWebEnginePage_WebAction_IDX                         = 54,
-    SBK_QWebEnginePage_FindFlag_IDX                          = 48,
+    SBK_QWebEngineFileSystemAccessRequest_IDX                = 23,
+    SBK_QWebEngineFindTextResult_IDX                         = 26,
+    SBK_QWebEngineFrame_IDX                                  = 27,
+    SBK_QWebEngineFullScreenRequest_IDX                      = 28,
+    SBK_QWebEngineGlobalSettings_SecureDnsMode_IDX           = 31,
+    SBK_QtWebEngineCoreQWebEngineGlobalSettings_IDX          = 29,
+    SBK_QWebEngineGlobalSettings_DnsMode_IDX                 = 30,
+    SBK_QWebEngineHistory_IDX                                = 32,
+    SBK_QWebEngineHistoryItem_IDX                            = 33,
+    SBK_QWebEngineHistoryModel_Roles_IDX                     = 35,
+    SBK_QWebEngineHistoryModel_IDX                           = 34,
+    SBK_QWebEngineHttpRequest_Method_IDX                     = 37,
+    SBK_QWebEngineHttpRequest_IDX                            = 36,
+    SBK_QWebEngineLoadingInfo_LoadStatus_IDX                 = 40,
+    SBK_QWebEngineLoadingInfo_ErrorDomain_IDX                = 39,
+    SBK_QWebEngineLoadingInfo_IDX                            = 38,
+    SBK_QWebEngineNavigationRequest_NavigationType_IDX       = 43,
+    SBK_QWebEngineNavigationRequest_NavigationRequestAction_IDX = 42,
+    SBK_QWebEngineNavigationRequest_IDX                      = 41,
+    SBK_QWebEngineNewWindowRequest_DestinationType_IDX       = 45,
+    SBK_QWebEngineNewWindowRequest_IDX                       = 44,
+    SBK_QWebEngineNotification_IDX                           = 46,
+    SBK_QWebEnginePage_WebAction_IDX                         = 56,
+    SBK_QWebEnginePage_FindFlag_IDX                          = 50,
     SBK_QFlags_QWebEnginePage_FindFlag_IDX                   = 3,
-    SBK_QWebEnginePage_WebWindowType_IDX                     = 55,
-    SBK_QWebEnginePage_PermissionPolicy_IDX                  = 52,
-    SBK_QWebEnginePage_NavigationType_IDX                    = 51,
-    SBK_QWebEnginePage_Feature_IDX                           = 46,
-    SBK_QWebEnginePage_FileSelectionMode_IDX                 = 47,
-    SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX     = 49,
-    SBK_QWebEnginePage_RenderProcessTerminationStatus_IDX    = 53,
-    SBK_QWebEnginePage_LifecycleState_IDX                    = 50,
-    SBK_QWebEnginePage_IDX                                   = 45,
-    SBK_QWebEnginePermission_PermissionType_IDX              = 57,
-    SBK_QWebEnginePermission_State_IDX                       = 58,
-    SBK_QWebEnginePermission_IDX                             = 56,
-    SBK_QWebEngineProfile_HttpCacheType_IDX                  = 60,
-    SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX        = 61,
-    SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX    = 62,
-    SBK_QWebEngineProfile_IDX                                = 59,
-    SBK_QWebEngineProfileBuilder_IDX                         = 63,
-    SBK_QWebEngineQuotaRequest_IDX                           = 64,
-    SBK_QWebEngineRegisterProtocolHandlerRequest_IDX         = 65,
-    SBK_QWebEngineScript_InjectionPoint_IDX                  = 67,
-    SBK_QWebEngineScript_ScriptWorldId_IDX                   = 68,
-    SBK_QWebEngineScript_IDX                                 = 66,
-    SBK_QWebEngineScriptCollection_IDX                       = 69,
-    SBK_QWebEngineSettings_FontFamily_IDX                    = 71,
-    SBK_QWebEngineSettings_WebAttribute_IDX                  = 75,
-    SBK_QWebEngineSettings_FontSize_IDX                      = 72,
-    SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX        = 74,
-    SBK_QWebEngineSettings_ImageAnimationPolicy_IDX          = 73,
-    SBK_QWebEngineSettings_IDX                               = 70,
-    SBK_QWebEngineUrlRequestInfo_ResourceType_IDX            = 78,
-    SBK_QWebEngineUrlRequestInfo_NavigationType_IDX          = 77,
-    SBK_QWebEngineUrlRequestInfo_IDX                         = 76,
-    SBK_QWebEngineUrlRequestInterceptor_IDX                  = 79,
-    SBK_QWebEngineUrlRequestJob_Error_IDX                    = 81,
-    SBK_QWebEngineUrlRequestJob_IDX                          = 80,
-    SBK_QWebEngineUrlScheme_Syntax_IDX                       = 85,
-    SBK_QWebEngineUrlScheme_SpecialPort_IDX                  = 84,
-    SBK_QWebEngineUrlScheme_Flag_IDX                         = 83,
+    SBK_QWebEnginePage_WebWindowType_IDX                     = 57,
+    SBK_QWebEnginePage_PermissionPolicy_IDX                  = 54,
+    SBK_QWebEnginePage_NavigationType_IDX                    = 53,
+    SBK_QWebEnginePage_Feature_IDX                           = 48,
+    SBK_QWebEnginePage_FileSelectionMode_IDX                 = 49,
+    SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX     = 51,
+    SBK_QWebEnginePage_RenderProcessTerminationStatus_IDX    = 55,
+    SBK_QWebEnginePage_LifecycleState_IDX                    = 52,
+    SBK_QWebEnginePage_IDX                                   = 47,
+    SBK_QWebEnginePermission_PermissionType_IDX              = 59,
+    SBK_QWebEnginePermission_State_IDX                       = 60,
+    SBK_QWebEnginePermission_IDX                             = 58,
+    SBK_QWebEngineProfile_HttpCacheType_IDX                  = 62,
+    SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX        = 63,
+    SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX    = 64,
+    SBK_QWebEngineProfile_IDX                                = 61,
+    SBK_QWebEngineProfileBuilder_IDX                         = 65,
+    SBK_QWebEngineQuotaRequest_IDX                           = 66,
+    SBK_QWebEngineRegisterProtocolHandlerRequest_IDX         = 67,
+    SBK_QWebEngineScript_InjectionPoint_IDX                  = 69,
+    SBK_QWebEngineScript_ScriptWorldId_IDX                   = 70,
+    SBK_QWebEngineScript_IDX                                 = 68,
+    SBK_QWebEngineScriptCollection_IDX                       = 71,
+    SBK_QWebEngineSettings_FontFamily_IDX                    = 73,
+    SBK_QWebEngineSettings_WebAttribute_IDX                  = 77,
+    SBK_QWebEngineSettings_FontSize_IDX                      = 74,
+    SBK_QWebEngineSettings_UnknownUrlSchemePolicy_IDX        = 76,
+    SBK_QWebEngineSettings_ImageAnimationPolicy_IDX          = 75,
+    SBK_QWebEngineSettings_IDX                               = 72,
+    SBK_QWebEngineUrlRequestInfo_ResourceType_IDX            = 80,
+    SBK_QWebEngineUrlRequestInfo_NavigationType_IDX          = 79,
+    SBK_QWebEngineUrlRequestInfo_IDX                         = 78,
+    SBK_QWebEngineUrlRequestInterceptor_IDX                  = 81,
+    SBK_QWebEngineUrlRequestJob_Error_IDX                    = 83,
+    SBK_QWebEngineUrlRequestJob_IDX                          = 82,
+    SBK_QWebEngineUrlScheme_Syntax_IDX                       = 87,
+    SBK_QWebEngineUrlScheme_SpecialPort_IDX                  = 86,
+    SBK_QWebEngineUrlScheme_Flag_IDX                         = 85,
     SBK_QFlags_QWebEngineUrlScheme_Flag_IDX                  = 4,
-    SBK_QWebEngineUrlScheme_IDX                              = 82,
-    SBK_QWebEngineUrlSchemeHandler_IDX                       = 86,
-    SBK_QWebEngineWebAuthPinRequest_IDX                      = 87,
-    SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX        = 92,
-    SBK_QWebEngineWebAuthUxRequest_PinEntryReason_IDX        = 90,
-    SBK_QWebEngineWebAuthUxRequest_PinEntryError_IDX         = 89,
-    SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX  = 91,
-    SBK_QWebEngineWebAuthUxRequest_IDX                       = 88,
-    SBK_QtWebEngineCore_IDX_COUNT                            = 93,
+    SBK_QWebEngineUrlScheme_IDX                              = 84,
+    SBK_QWebEngineUrlSchemeHandler_IDX                       = 88,
+    SBK_QWebEngineWebAuthPinRequest_IDX                      = 89,
+    SBK_QWebEngineWebAuthUxRequest_WebAuthUxState_IDX        = 94,
+    SBK_QWebEngineWebAuthUxRequest_PinEntryReason_IDX        = 92,
+    SBK_QWebEngineWebAuthUxRequest_PinEntryError_IDX         = 91,
+    SBK_QWebEngineWebAuthUxRequest_RequestFailureReason_IDX  = 93,
+    SBK_QWebEngineWebAuthUxRequest_IDX                       = 90,
+    SBK_QtWebEngineCore_IDX_COUNT                            = 95,
 };
 
 // This variable stores all Python types exported by this module.
@@ -278,23 +284,24 @@ enum [[deprecated]] : int {
     SBK_QTWEBENGINECORE_QLIST_INT_IDX                        = 0, // QList<int>
     SBK_QTWEBENGINECORE_QHASH_QBYTEARRAY_QBYTEARRAY_IDX      = 1, // QHash<QByteArray,QByteArray>
     SBK_QTWEBENGINECORE_QLIST_QWEBENGINESCRIPT_IDX           = 2, // QList<QWebEngineScript>
-    SBK_QTWEBENGINECORE_QMULTIMAP_QBYTEARRAY_QBYTEARRAY_IDX  = 3, // QMultiMap<QByteArray,QByteArray>
-    SBK_QTWEBENGINECORE_QLIST_QWEBENGINEFRAME_IDX            = 4, // QList<QWebEngineFrame>
-    SBK_QTWEBENGINECORE_QLIST_QSSLCERTIFICATE_IDX            = 5, // QList<QSslCertificate>
+    SBK_QTWEBENGINECORE_QLIST_QSSLCERTIFICATE_IDX            = 3, // QList<QSslCertificate>
+    SBK_QTWEBENGINECORE_QMULTIMAP_QBYTEARRAY_QBYTEARRAY_IDX  = 4, // QMultiMap<QByteArray,QByteArray>
+    SBK_QTWEBENGINECORE_QLIST_QWEBENGINEFRAME_IDX            = 5, // QList<QWebEngineFrame>
     SBK_QTWEBENGINECORE_QMAP_QBYTEARRAY_QBYTEARRAY_IDX       = 6, // QMap<QByteArray,QByteArray>
     SBK_QTWEBENGINECORE_QLIST_QURL_IDX                       = 7, // QList<QUrl>
     SBK_QTWEBENGINECORE_QLIST_QWEBENGINEPERMISSION_IDX       = 8, // QList<QWebEnginePermission>
     SBK_QTWEBENGINECORE_QLIST_QWEBENGINEHISTORYITEM_IDX      = 9, // QList<QWebEngineHistoryItem>
-    SBK_QTWEBENGINECORE_QMAP_QSTRING_QVARIANT_IDX            = 10, // QMap<QString,QVariant>
-    SBK_QTWEBENGINECORE_STD_PAIR_BOOL_QSTRING_IDX            = 11, // std::pair<bool,QString>
-    SBK_QTWEBENGINECORE_QLIST_QBYTEARRAY_IDX                 = 12, // QList<QByteArray>
-    SBK_QTWEBENGINECORE_QMAP_QSTRING_QSTRING_IDX             = 13, // QMap<QString,QString>
-    SBK_QTWEBENGINECORE_QMAP_INT_QVARIANT_IDX                = 14, // QMap<int,QVariant>
-    SBK_QTWEBENGINECORE_QLIST_QMODELINDEX_IDX                = 15, // QList<QModelIndex>
-    SBK_QTWEBENGINECORE_QHASH_INT_QBYTEARRAY_IDX             = 16, // QHash<int,QByteArray>
-    SBK_QTWEBENGINECORE_QLIST_QVARIANT_IDX                   = 17, // QList<QVariant>
-    SBK_QTWEBENGINECORE_QLIST_QSTRING_IDX                    = 18, // QList<QString>
-    SBK_QTWEBENGINECORE_CONVERTERS_IDX_COUNT                 = 19,
+    SBK_QTWEBENGINECORE_QLIST_QWEBENGINEEXTENSIONINFO_IDX    = 10, // QList<QWebEngineExtensionInfo>
+    SBK_QTWEBENGINECORE_QMAP_QSTRING_QVARIANT_IDX            = 11, // QMap<QString,QVariant>
+    SBK_QTWEBENGINECORE_STD_PAIR_BOOL_QSTRING_IDX            = 12, // std::pair<bool,QString>
+    SBK_QTWEBENGINECORE_QLIST_QBYTEARRAY_IDX                 = 13, // QList<QByteArray>
+    SBK_QTWEBENGINECORE_QMAP_QSTRING_QSTRING_IDX             = 14, // QMap<QString,QString>
+    SBK_QTWEBENGINECORE_QMAP_INT_QVARIANT_IDX                = 15, // QMap<int,QVariant>
+    SBK_QTWEBENGINECORE_QLIST_QMODELINDEX_IDX                = 16, // QList<QModelIndex>
+    SBK_QTWEBENGINECORE_QHASH_INT_QBYTEARRAY_IDX             = 17, // QHash<int,QByteArray>
+    SBK_QTWEBENGINECORE_QLIST_QVARIANT_IDX                   = 18, // QList<QVariant>
+    SBK_QTWEBENGINECORE_QLIST_QSTRING_IDX                    = 19, // QList<QString>
+    SBK_QTWEBENGINECORE_CONVERTERS_IDX_COUNT                 = 20,
 };
 
 // Converter indices
@@ -302,23 +309,24 @@ enum : int {
     SBK_QtWebEngineCore_QList_int_IDX                        = 0, // QList<int>
     SBK_QtWebEngineCore_QHash_QByteArray_QByteArray_IDX      = 1, // QHash<QByteArray,QByteArray>
     SBK_QtWebEngineCore_QList_QWebEngineScript_IDX           = 2, // QList<QWebEngineScript>
-    SBK_QtWebEngineCore_QMultiMap_QByteArray_QByteArray_IDX  = 3, // QMultiMap<QByteArray,QByteArray>
-    SBK_QtWebEngineCore_QList_QWebEngineFrame_IDX            = 4, // QList<QWebEngineFrame>
-    SBK_QtWebEngineCore_QList_QSslCertificate_IDX            = 5, // QList<QSslCertificate>
+    SBK_QtWebEngineCore_QList_QSslCertificate_IDX            = 3, // QList<QSslCertificate>
+    SBK_QtWebEngineCore_QMultiMap_QByteArray_QByteArray_IDX  = 4, // QMultiMap<QByteArray,QByteArray>
+    SBK_QtWebEngineCore_QList_QWebEngineFrame_IDX            = 5, // QList<QWebEngineFrame>
     SBK_QtWebEngineCore_QMap_QByteArray_QByteArray_IDX       = 6, // QMap<QByteArray,QByteArray>
     SBK_QtWebEngineCore_QList_QUrl_IDX                       = 7, // QList<QUrl>
     SBK_QtWebEngineCore_QList_QWebEnginePermission_IDX       = 8, // QList<QWebEnginePermission>
     SBK_QtWebEngineCore_QList_QWebEngineHistoryItem_IDX      = 9, // QList<QWebEngineHistoryItem>
-    SBK_QtWebEngineCore_QMap_QString_QVariant_IDX            = 10, // QMap<QString,QVariant>
-    SBK_QtWebEngineCore_std_pair_bool_QString_IDX            = 11, // std::pair<bool,QString>
-    SBK_QtWebEngineCore_QList_QByteArray_IDX                 = 12, // QList<QByteArray>
-    SBK_QtWebEngineCore_QMap_QString_QString_IDX             = 13, // QMap<QString,QString>
-    SBK_QtWebEngineCore_QMap_int_QVariant_IDX                = 14, // QMap<int,QVariant>
-    SBK_QtWebEngineCore_QList_QModelIndex_IDX                = 15, // QList<QModelIndex>
-    SBK_QtWebEngineCore_QHash_int_QByteArray_IDX             = 16, // QHash<int,QByteArray>
-    SBK_QtWebEngineCore_QList_QVariant_IDX                   = 17, // QList<QVariant>
-    SBK_QtWebEngineCore_QList_QString_IDX                    = 18, // QList<QString>
-    SBK_QtWebEngineCore_CONVERTERS_IDX_COUNT                 = 19,
+    SBK_QtWebEngineCore_QList_QWebEngineExtensionInfo_IDX    = 10, // QList<QWebEngineExtensionInfo>
+    SBK_QtWebEngineCore_QMap_QString_QVariant_IDX            = 11, // QMap<QString,QVariant>
+    SBK_QtWebEngineCore_std_pair_bool_QString_IDX            = 12, // std::pair<bool,QString>
+    SBK_QtWebEngineCore_QList_QByteArray_IDX                 = 13, // QList<QByteArray>
+    SBK_QtWebEngineCore_QMap_QString_QString_IDX             = 14, // QMap<QString,QString>
+    SBK_QtWebEngineCore_QMap_int_QVariant_IDX                = 15, // QMap<int,QVariant>
+    SBK_QtWebEngineCore_QList_QModelIndex_IDX                = 16, // QList<QModelIndex>
+    SBK_QtWebEngineCore_QHash_int_QByteArray_IDX             = 17, // QHash<int,QByteArray>
+    SBK_QtWebEngineCore_QList_QVariant_IDX                   = 18, // QList<QVariant>
+    SBK_QtWebEngineCore_QList_QString_IDX                    = 19, // QList<QString>
+    SBK_QtWebEngineCore_CONVERTERS_IDX_COUNT                 = 20,
 };
 // Macros for type check
 
@@ -346,6 +354,8 @@ template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::DownloadSt
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::SavePageFormat >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::DownloadInterruptReason >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_DownloadInterruptReason_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QWebEngineExtensionInfo >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineExtensionInfo_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QWebEngineExtensionManager >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineExtensionManager_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineFileSystemAccessRequest::HandleType >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_HandleType_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineFileSystemAccessRequest::AccessFlag >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFileSystemAccessRequest_AccessFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QWebEngineFileSystemAccessRequest::AccessFlag> >() { return Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineFileSystemAccessRequest_AccessFlag_IDX]); }
